CREATE OR REPLACE VIEW V_RESERVATION AS (
  SELECT RE.ID AS ID_REZERVAC, RE.ID_LASTNIKA, RE.ID_PLOVILA, RE.VRSTA, RE.ID_POGODBE, RE.STATUS_REZERVAC, RE.KOMENTAR, RE.DATUM_REZERVACIJE, RE.DATUM_DO, RE.PRIVEZ, RE.ID_PRIVEZ, NNPR.NNLOCATION_ID,
  DE.ID_REZERVAC_DETAIL AS REZERVAC_DETAIL_ID, DE.DATUM_OD AS REZERVAC_DETAIL_DATUM_OD, DE.DATUM_DO AS REZERVAC_DETAIL_DATUM_DO, DE.STATUS_REZERVAC AS REZERVAC_DETAIL_STATUS, DE.COMPLETE AS REZERVAC_DETAIL_COMPLETE,
  NND.N_PRIVEZA AS REZERVAC_DETAIL_PRIVEZ, NND.ID_PRIVEZ AS REZERVAC_DETAIL_ID_PRIVEZ, NNPD.NNLOCATION_ID AS REZERVAC_DETAIL_NNLOCATION_ID, 
  KU.IME AS KUPCI_IME, KU.PRIIMEK AS KUPCI_PRIIMEK,
  (CASE WHEN RE.ID_LASTNIKA IS NULL OR RE.ID_LASTNIKA = 0 THEN RE.NAZIV ELSE KU.PRIIMEK END) AS NAZIV,
  (CASE WHEN RE.ID_PLOVILA IS NULL OR RE.ID_PLOVILA = 0 THEN RE.PLOVILO ELSE PL.IME END) AS PLOVILO,
  (CASE WHEN RE.ID_PLOVILA IS NULL OR RE.ID_PLOVILA = 0 THEN RE.DOLZINA ELSE PL.DOLZINA END) AS DOLZINA,
  (CASE WHEN RE.ID_PLOVILA IS NULL OR RE.ID_PLOVILA = 0 THEN RE.SIRINA ELSE PL.SIRINA END) AS SIRINA,
  (CASE WHEN RE.ID_PLOVILA IS NULL OR RE.ID_PLOVILA = 0 THEN RE.NTIP ELSE PL.NTIP END) AS NTIP,
  (CASE WHEN RE.ID_PLOVILA IS NULL OR RE.ID_PLOVILA = 0 THEN NULL ELSE PL.NZASTAVA END) AS NZASTAVA,
  (CASE WHEN RE.STATUS_REZERVAC IN (1, 2) THEN 'Y' ELSE 'N' END) AS RECEIVED,
  (CASE WHEN RE.STATUS_REZERVAC = 0 THEN 'Y' ELSE 'N' END) AS DEPARTED,
  (CASE WHEN (
    -- Fully charged pomeni, da ima neka rezervacija za celotno obdobje kreirane obračunane storitve -> to rešimo s seštevanjem števila dni, ki jih pokrivajo posamezne storitve,
    -- in to primerjamo s številom dni med celotnim rezervacijskim obdobjem. Če je število pokritih dni >= števila dni celotnega obdobja, potem je to fully charged, drugače ni.
    SELECT SUM(
      -- Prvi trije primeri so za primere, kjer imamo vpisan datum_do na storitvi (posamezne primere moramo ločiti, ker je treba vzeti različne datume za odštevanje, odvisno od datumov na storitvi)
      CASE WHEN M.DATUM_DO IS NOT NULL AND TRUNC(M.DATUM_OD) <= TRUNC(RE.DATUM_REZERVACIJE) AND TRUNC(M.DATUM_DO) >= TRUNC(RE.DATUM_REZERVACIJE) AND TRUNC(M.DATUM_DO) <= TRUNC(RE.DATUM_DO) 
        THEN (CASE WHEN ROWNUM = 1 THEN (M.DATUM_DO - RE.DATUM_REZERVACIJE) ELSE (M.DATUM_DO - RE.DATUM_REZERVACIJE) + 1 END)
      WHEN M.DATUM_DO IS NOT NULL AND TRUNC(M.DATUM_OD) >= TRUNC(RE.DATUM_REZERVACIJE) AND TRUNC(M.DATUM_DO) <= TRUNC(RE.DATUM_DO) 
        THEN (CASE WHEN ROWNUM = 1 THEN (M.DATUM_DO - M.DATUM_OD) ELSE (M.DATUM_DO - M.DATUM_OD) + 1 END)        
      WHEN M.DATUM_DO IS NOT NULL AND TRUNC(M.DATUM_DO) >= TRUNC(RE.DATUM_DO) AND TRUNC(M.DATUM_OD) >= TRUNC(RE.DATUM_REZERVACIJE) AND TRUNC(M.DATUM_OD) <= TRUNC(RE.DATUM_DO) 
        THEN (CASE WHEN ROWNUM = 1 THEN (RE.DATUM_DO - M.DATUM_OD) ELSE (RE.DATUM_DO - M.DATUM_OD) + 1 END)  
      
      -- Naslednji trije primeri so za primere, kjer nimamo datuma_do na storitvi
      WHEN M.DATUM_DO IS NULL AND TRUNC(M.DATUM_OD) <= TRUNC(RE.DATUM_REZERVACIJE) 
        THEN (CASE WHEN ROWNUM = 1 THEN (RE.DATUM_DO - RE.DATUM_REZERVACIJE) ELSE (RE.DATUM_DO - RE.DATUM_REZERVACIJE) + 1 END)  
      WHEN M.DATUM_DO IS NULL AND TRUNC(M.DATUM_OD) >= TRUNC(RE.DATUM_REZERVACIJE) AND TRUNC(M.DATUM_OD) <= TRUNC(RE.DATUM_DO) 
        THEN (CASE WHEN ROWNUM = 1 THEN (RE.DATUM_DO - M.DATUM_OD) ELSE (RE.DATUM_DO - M.DATUM_OD) + 1 END)  
      ELSE 0 END
    )
    FROM M_STORITVE M, M_NNSTOMAR MS WHERE MS.SIFRA = M.STORITEV AND MS.DEPARTURE_CHECK = 'Y' AND M.N_RACUNA IS NOT NULL AND M.N_RACUNA <> 'STORNO'
    AND TRUNC(M.DATUM_OD) < TRUNC(RE.DATUM_DO) AND (M.DATUM_DO IS NULL OR M.DATUM_DO >= RE.DATUM_REZERVACIJE) AND M.ID_LASTNIKA = RE.ID_LASTNIKA AND M.ID_PLOVILA = RE.ID_PLOVILA
    AND M.NNLOCATION_ID = NNPR.NNLOCATION_ID 
    
  ) >= RE.DATUM_DO - RE.DATUM_REZERVACIJE THEN 'Y' ELSE 'N'  END) AS FULLY_CHARGED
  FROM REZERVAC RE
  JOIN REZERVAC_DETAIL DE ON RE.ID = DE.ID_REZERVAC
  LEFT OUTER JOIN KUPCI KU ON KU.ID = RE.ID_LASTNIKA
  LEFT OUTER JOIN PLOVILA PL ON PL.ID = RE.ID_PLOVILA
  LEFT OUTER JOIN NNPRIVEZ NND ON NND.ID_PRIVEZ = DE.ID_PRIVEZ
  LEFT OUTER JOIN NNPOMOL NNPD ON NNPD.SIFRA = NND.KATEGORIJA
  LEFT OUTER JOIN NNPRIVEZ NNR ON NNR.ID_PRIVEZ = RE.ID_PRIVEZ
  LEFT OUTER JOIN NNPOMOL NNPR ON NNPR.SIFRA = NNR.KATEGORIJA
);

insert into verzije_baza
(id, dt_vpis, verzija, ver_nr, opis) values (1108, SYSDATE, '5.5', 1028, 'VReservation')
;
